<?php
namespace Ak\Mailchimp\Entity\MailingList;
use DateTime;

/**
 * Pretplatnik liste.
 *
 * @package Ak\Mailchimp\Entity\MailingList
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class Member
{
    /** @var null|string */
    private $id;
    /** @var string */
    private $email_address;
    /** @var string */
    private $unique_email_id;
    /** @var string */
    private $email_type;
    /** @var string */
    private $status;
    /** @var string */
    private $unsubscribe_reason;
    /** @var array */
    private $merge_fields;
    /** @var array */
    private $interests;
    /** @var Member\Stats */
    private $stats;
    /** @var string */
    private $ip_signup;
    /** @var DateTime */
    private $timestamp_signup;
    /** @var string */
    private $ip_opt;
    /** @var DateTime */
    private $timestamp_opt;
    /** @var int */
    private $member_rating;
    /** @var DateTime */
    private $last_changed;
    /** @var string */
    private $language;
    /** @var bool */
    private $vip;
    /** @var string */
    private $email_client;
    /** @var Member\Location */
    private $location;
    /** @var Member\MarketingPermission[] */
    private $marketing_permissions;
    /** @var Member\Note */
    private $last_note;
    /** @var int */
    private $tags_count;
    /** @var array */
    private $tags;
    /** @var string */
    private $list_id;

    /**
     * @return string
     */
    public function getId(): ?string
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getEmailAddress(): string
    {
        return $this->email_address;
    }

    /**
     * @param string $email_address
     */
    public function setEmailAddress(string $email_address): void
    {
        $this->email_address = $email_address;
    }

    /**
     * @return string
     */
    public function getUniqueEmailId(): string
    {
        return $this->unique_email_id;
    }

    /**
     * @return string
     */
    public function getEmailType(): string
    {
        return $this->email_type;
    }

    /**
     * @param string $email_type
     */
    public function setEmailType(string $email_type): void
    {
        $this->email_type = $email_type;
    }

    /**
     * @return string
     */
    public function getStatus(): string
    {
        return $this->status;
    }

    /**
     * @param string $status
     */
    public function setStatus(string $status): void
    {
        $this->status = $status;
    }

    /**
     * @return string
     */
    public function getUnsubscribeReason(): string
    {
        return $this->unsubscribe_reason;
    }

    /**
     * @param string $unsubscribe_reason
     */
    public function setUnsubscribeReason(string $unsubscribe_reason): void
    {
        $this->unsubscribe_reason = $unsubscribe_reason;
    }

    /**
     * @return array
     */
    public function getMergeFields(): array
    {
        return $this->merge_fields;
    }

    /**
     * @param array $merge_fields
     */
    public function setMergeFields(array $merge_fields): void
    {
        $this->merge_fields = $merge_fields;
    }

    /**
     * @return array
     */
    public function getInterests(): array
    {
        return $this->interests;
    }

    /**
     * @param array $interests
     */
    public function setInterests(array $interests): void
    {
        $this->interests = $interests;
    }

    /**
     * @return Member\Stats
     */
    public function getStats(): Member\Stats
    {
        return $this->stats;
    }

    /**
     * @return string
     */
    public function getIpSignup(): string
    {
        return $this->ip_signup;
    }

    /**
     * @return DateTime
     */
    public function getTimestampSignup(): DateTime
    {
        return $this->timestamp_signup;
    }

    /**
     * @return string
     */
    public function getIpOpt(): string
    {
        return $this->ip_opt;
    }

    /**
     * @return DateTime
     */
    public function getTimestampOpt(): DateTime
    {
        return $this->timestamp_opt;
    }

    /**
     * @return int
     */
    public function getMemberRating(): int
    {
        return $this->member_rating;
    }

    /**
     * @return DateTime
     */
    public function getLastChanged(): DateTime
    {
        return $this->last_changed;
    }

    /**
     * @return string
     */
    public function getLanguage(): string
    {
        return $this->language;
    }

    /**
     * @param string $language
     */
    public function setLanguage(string $language): void
    {
        $this->language = $language;
    }

    /**
     * @return bool
     */
    public function isVip(): bool
    {
        return $this->vip;
    }

    /**
     * @param bool $vip
     */
    public function setVip(bool $vip): void
    {
        $this->vip = $vip;
    }

    /**
     * @return string
     */
    public function getEmailClient(): string
    {
        return $this->email_client;
    }

    /**
     * @return Member\Location
     */
    public function getLocation(): Member\Location
    {
        return $this->location;
    }

    /**
     * @param Member\Location $location
     */
    public function setLocation(Member\Location $location): void
    {
        $this->location = $location;
    }

    /**
     * @return Member\MarketingPermission[]
     */
    public function getMarketingPermissions(): array
    {
        return $this->marketing_permissions;
    }

    /**
     * @param Member\MarketingPermission[] $marketing_permissions
     */
    public function setMarketingPermissions(array $marketing_permissions): void
    {
        $this->marketing_permissions = $marketing_permissions;
    }

    /**
     * @return Member\Note
     */
    public function getLastNote(): Member\Note
    {
        return $this->last_note;
    }

    /**
     * @return int
     */
    public function getTagsCount(): int
    {
        return $this->tags_count;
    }

    /**
     * @return array
     */
    public function getTags(): array
    {
        return $this->tags;
    }

    /**
     * @param array $tags
     */
    public function setTags(array $tags): void
    {
        $this->tags = $tags;
    }

    /**
     * @return string
     */
    public function getListId(): string
    {
        return $this->list_id;
    }
}