<?php
namespace Ak\Mailchimp\Entity\MailingList;

use DateTime;

/**
 * Statistika za ovu mailing listu.
 *
 * @package Ak\Mailchimp\Entity
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class Stats
{
    /** @var int */
    private $member_count;
    /** @var int */
    private $unsubscribe_count;
    /** @var int */
    private $cleaned_count;
    /** @var int */
    private $member_count_since_send;
    /** @var int */
    private $unsubscribe_count_since_send;
    /** @var int */
    private $cleaned_count_since_send;
    /** @var int */
    private $campaign_count;
    /** @var DateTime */
    private $campaign_last_sent;
    /** @var int */
    private $merge_field_count;
    /** @var float */
    private $avg_sub_rate;
    /** @var float */
    private $avg_unsub_rate;
    /** @var float */
    private $target_sub_rate;
    /** @var float */
    private $open_rate;
    /** @var float */
    private $click_rate;
    /** @var DateTime */
    private $last_sub_date;
    /** @var DateTime */
    private $last_unsub_date;

    /**
     * @return int
     */
    public function getMemberCount(): int
    {
        return $this->member_count ?? 0;
    }

    /**
     * @return int
     */
    public function getUnsubscribeCount(): int
    {
        return $this->unsubscribe_count ?? 0;
    }

    /**
     * @return int
     */
    public function getCleanedCount(): int
    {
        return $this->cleaned_count ?? 0;
    }

    /**
     * @return int
     */
    public function getMemberCountSinceSend(): int
    {
        return $this->member_count_since_send ?? 0;
    }

    /**
     * @return int
     */
    public function getUnsubscribeCountSinceSend(): int
    {
        return $this->unsubscribe_count_since_send ?? 0;
    }

    /**
     * @return int
     */
    public function getCleanedCountSinceSend(): int
    {
        return $this->cleaned_count_since_send ?? 0;
    }

    /**
     * @return int
     */
    public function getCampaignCount(): int
    {
        return $this->campaign_count ?? 0;
    }

    /**
     * @return DateTime
     */
    public function getCampaignLastSent(): DateTime
    {
        return $this->campaign_last_sent ?? DateTime::createFromFormat(DateTime::ISO8601, '0000-00-00T00:00:00+0000');
    }

    /**
     * @return int
     */
    public function getMergeFieldCount(): int
    {
        return $this->merge_field_count ?? 0;
    }

    /**
     * @return float
     */
    public function getAvgSubRate(): float
    {
        return $this->avg_sub_rate ?? 0.0;
    }

    /**
     * @return float
     */
    public function getAvgUnsubRate(): float
    {
        return $this->avg_unsub_rate ?? 0.0;
    }

    /**
     * @return float
     */
    public function getTargetSubRate(): float
    {
        return $this->target_sub_rate ?? 0.0;
    }

    /**
     * @return float
     */
    public function getOpenRate(): float
    {
        return $this->open_rate ?? 0.0;
    }

    /**
     * @return float
     */
    public function getClickRate(): float
    {
        return $this->click_rate ?? 0.0;
    }

    /**
     * @return DateTime
     */
    public function getLastSubDate(): DateTime
    {
        return $this->last_sub_date ?? DateTime::createFromFormat(DateTime::ISO8601, '0000-00-00T00:00:00+0000');
    }

    /**
     * @return DateTime
     */
    public function getLastUnsubDate(): DateTime
    {
        return $this->last_unsub_date ?? DateTime::createFromFormat(DateTime::ISO8601, '0000-00-00T00:00:00+0000');
    }
}