<?php
namespace Ak\Mailchimp\Gateway;

use Interop\Container\ContainerInterface;
use Laminas\Hydrator\DelegatingHydrator;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Kreira novu instancu mailchimp gatewaya.
 *
 * @package Ak\Mailchimp\Gateway
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class GatewayFactory implements FactoryInterface
{
    /**
     * Kreira instancu.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return AbstractGateway
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $http = $container->get('mailchimp.http');
        $hydrators = $container->get(HydratorPluginManager::class);
        $hydrator = new DelegatingHydrator($hydrators);

        return new $requestedName($http, $hydrator);
    }
}
