<?php
namespace Ak\Mailchimp\Hydrator\Entity\MailingList;

use Ak\Hydrator\ReadOnlyHydrator;
use Ak\Hydrator\Strategy\HydratorStrategy;
use Ak\Mailchimp\Entity\MailingList\Member\Location;
use Ak\Mailchimp\Entity\MailingList\Member\MarketingPermission;
use Ak\Mailchimp\Entity\MailingList\Member\Note;
use Ak\Mailchimp\Entity\MailingList\Member\Stats;
use Laminas\Hydrator\ClassMethods;
use Laminas\Hydrator\Strategy\CollectionStrategy;
use Laminas\Hydrator\Strategy\DateTimeFormatterStrategy;

/**
 * Hidrira pretplatnike liste.
 *
 * @package Ak\Mailchimp\Hydrator\Entity\MailingList
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class MemberHydrator extends ReadOnlyHydrator
{
    /**
     * Konstruktor.
     */
    public function __construct()
    {
        parent::__construct();

        $datetimeStrategy = new DateTimeFormatterStrategy(\DateTime::ISO8601);

        $this->addStrategy('stats', new HydratorStrategy(new ClassMethods(), Stats::class));
        $this->addStrategy('timestamp_signup', $datetimeStrategy);
        $this->addStrategy('timestamp_opt', $datetimeStrategy);
        $this->addStrategy('last_changed', $datetimeStrategy);
        $this->addStrategy('location', new HydratorStrategy(new ReadOnlyHydrator(), Location::class));
        $this->addStrategy('marketing_permissions', new CollectionStrategy(new ClassMethods(), MarketingPermission::class));
        $this->addStrategy('last_note', new HydratorStrategy(new ReadOnlyHydrator(), Note::class));
    }
}
