<?php
namespace AkTest\Mailchimp\Entity\MailingList;

use Ak\Mailchimp\Entity\MailingList\Stats;
use AkTest\Mailchimp\AbstractTestCase;
use DateTime;
use Zend\Hydrator\HydratorInterface;
use Zend\Hydrator\HydratorPluginManager;
use Zend\ServiceManager\PluginManagerInterface;

/**
 * Class MailingListStatsTest
 *
 * @package AkTest\Mailchimp\Entity\MailingList
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class StatsTest extends AbstractTestCase
{
    public function testHydratorCanExchangeEntity()
    {
        $container = $this->getContainer();
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);
        /** @var HydratorInterface $hydrator */
        $hydrator = $hydrators->get(Stats::class);

        $data = [
            'member_count' => 123,
            'unsubscribe_count' => 5632,
            'cleaned_count' => 24,
            'member_count_since_send' => 62,
            'unsubscribe_count_since_send' => 51,
            'cleaned_count_since_send' => 254,
            'campaign_count' => 235,
            'campaign_last_sent' => '2018-02-17T14:24:45+0200',
            'merge_field_count' => 146,
            'avg_sub_rate' => 13.5423,
            'avg_unsub_rate' => 15.342,
            'target_sub_rate' => 123.5345,
            'open_rate' => 154.234,
            'click_rate' => 134.234,
            'last_sub_date' => '2018-10-01T07:54:44+0200',
            'last_unsub_date' => '2018-10-02T21:12:45+0200',
        ];

        /** @var Stats $stats */
        $stats = $hydrator->hydrate($data, new Stats());

        $this->assertEquals($data['member_count'], $stats->getMemberCount());
        $this->assertEquals($data['unsubscribe_count'], $stats->getUnsubscribeCount());
        $this->assertEquals($data['cleaned_count'], $stats->getCleanedCount());
        $this->assertEquals($data['member_count_since_send'], $stats->getMemberCountSinceSend());
        $this->assertEquals($data['unsubscribe_count_since_send'], $stats->getUnsubscribeCountSinceSend());
        $this->assertEquals($data['cleaned_count'], $stats->getCleanedCount());
        $this->assertEquals($data['campaign_count'], $stats->getCampaignCount());
        $this->assertEquals($data['campaign_last_sent'], $stats->getCampaignLastSent()->format(DateTime::ISO8601));
        $this->assertEquals($data['merge_field_count'], $stats->getMergeFieldCount());
        $this->assertEquals($data['avg_sub_rate'], $stats->getAvgSubRate());
        $this->assertEquals($data['avg_unsub_rate'], $stats->getAvgUnsubRate());
        $this->assertEquals($data['target_sub_rate'], $stats->getTargetSubRate());
        $this->assertEquals($data['open_rate'], $stats->getOpenRate());
        $this->assertEquals($data['click_rate'], $stats->getClickRate());
        $this->assertEquals($data['last_sub_date'], $stats->getLastSubDate()->format(DateTime::ISO8601));
        $this->assertEquals($data['last_unsub_date'], $stats->getLastUnsubDate()->format(DateTime::ISO8601));

        $extracted = $hydrator->extract($stats);

        $this->assertEquals($data, $extracted);
    }
}